/***************************************************************************
 *   Copyright (C) 2003-2004 by Flameeyes                                  *
 *   dgp85@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#include "addfavorites.h"
#include "kvba.h"

#include <qfile.h>
#include <qlineedit.h>

#include <klistview.h>
#include <kconfig.h>
#include <kfiledialog.h>
#include <kmessagebox.h>
#include <kurlrequester.h>

AddFavorites::AddFavorites(QWidget *parent, const char *name, WFlags f)
 : uiAddFavorites(parent, name, f)
{
	romPath->setMode(KFile::LocalOnly);
	ipsPath->setMode(KFile::LocalOnly);
	cfgPath->setMode(KFile::LocalOnly);
}


AddFavorites::~AddFavorites()
{
}

void AddFavorites::accept()
{
	if ( ! QFile::exists(KURL( romPath->url() ).path()))
	{
		KMessageBox::sorry( this, tr("ROM file not found"), tr("Error, impossible to add the favorite!") );
		return;
	}

	if ( !KURL( ipsPath->url() ).path().isEmpty() && ! QFile::exists(KURL( ipsPath->url() ).path()))
	{
		KMessageBox::sorry( this, tr("IPS patch file not found"), tr("Warning") );
		romPath->clear();
	}

	if ( ! parent()->inherits("kvba") )
		return;
	
	KvbaMain *mainwidget = const_cast<KvbaMain*>( reinterpret_cast<const KvbaMain*>( parent() ) );
	
	new KListViewItem(
		mainwidget->favorites,
		gameName->text(),
		KURL( romPath->url() ).path(),
		KURL( ipsPath->url() ).path()
		);

	KGlobal::config()->setGroup("favorites");
		QStringList l;
		l += gameName->text();
		l += KURL( romPath->url() ).path();
		l += KURL( ipsPath->url() ).path();
		l += KURL( cfgPath->url() ).path();
		KGlobal::config()->writePathEntry(
			QString("fav") + QString::number( KGlobal::config()->entryMap("favorites").size() ),
			l
			);
	
	QDialog::accept();
}

void AddFavorites::reject()
{
	QDialog::reject();
}
